@@ -59,10 +59,6 @@ class HttpClient:
             r = requests.request(method, url, headers=headers, params=params, json=body, verify=False, proxies=self.proxies)
 
         if r.status_code >= 400:
-            with open("buceta.json", "w") as f:
-                import json
-
-                json.dump(body, f, indent=2)
             raise Exception(
                 f"Error making request to {url}: {r}. Parameters: {params}, Body: {body}, Response: {r.text}, Headers: {r.headers}"
             )
